paralelocs_qlikapi package — documentação Paralelo CS Qlik API SDK for Python 0.2.5

# paralelocs_qlikapi package

## Subpackages

- paralelocs_qlikapi.api package
  - Submodules
  - paralelocs_qlikapi.api.api module
  - paralelocs_qlikapi.api.auth module
  - Module contents
- paralelocs_qlikapi.method package
  - Submodules
  - paralelocs_qlikapi.method.app module
  - paralelocs_qlikapi.method.base module
  - paralelocs_qlikapi.method.reloadtask module
  - paralelocs_qlikapi.method.stream module
  - paralelocs_qlikapi.method.tag module
  - paralelocs_qlikapi.method.task module
  - Module contents

## Submodules

## paralelocs_qlikapi.cli module

Module that contains the command line app.

Why does this file exist, and why not put this in __main__?

> You might be tempted to import things from __main__ later, but that will cause problems: the code will get executed twice:

> - When you run python -mparalelocs_qlikapi python will execute `__main__.py` as a script. That means there won’t be any `paralelocs_qlikapi.__main__` in `sys.modules`.

> - When you import __main__ it will get executed again (as a module) because there’s no `paralelocs_qlikapi.__main__` in `sys.modules`.

> Also see (1) from http://click.pocoo.org/5/setuptools/#setuptools-integration

`paralelocs_qlikapi.cli.` `main`(args=None)

## Module contents

Top-level package for Python Qlik API QRS.